#!/usr/bin/perl -w
#----------------------------------------------------------------------------
# /var/install/bin/perl-print-module-files.pl - print perl module files
#
# Creation:     2009-02-23 jed
# Last Update:  $Id: perl-print-module-files.pl 60131 2018-11-12 20:44:03Z hbfl $
#
# Copyright (c) 2002-2024 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

use strict;
use IO::Dir;
use ExtUtils::Packlist;
use ExtUtils::Installed;

sub emptydir($)
  {
    my ($dir) = @_;
    my $dh = IO::Dir->new($dir) || return(0);
    my @count = $dh->read();
    $dh->close();
    return(@count == 2 ? 1 : 0);
  }

# Find all the installed packages
print("Finding all installed modules...\n");
my $installed = ExtUtils::Installed->new();

foreach my $module (grep(!/^Perl$/, $installed->modules()))
  {
    my $version = $installed->version($module) || "???";
    print("\nFound module $module Version $version\n");

    print("- Do you want to show $module files? [n] ");
    my $r = <STDIN>; chomp($r);
    if ($r && $r =~ /^y/i)
      {
        # show all files
        foreach my $file (sort($installed->files($module)))
          {
            print("  - $file\n");
          }

        my $pf = $installed->packlist($module)->packlist_file();
        print("  - $pf\n");
      }
  }
